envie/inspect

Types

pub type InspectData {
  InspectData(fields: List(schema.InspectField))
}

Constructors

Values

pub fn load_with_trace(
  a: schema.Schema(b),
) -> Result(#(b, InspectData), error.Error)

Load a schema and return both the parsed config and inspection data.

pub fn snapshot(a: schema.Schema(b)) -> InspectData

Return a snapshot of the schema fields with decoded values, defaults, errors, and secret masking.

Search Document